.. module:: qepy.io

The QEInput object
=========================


The :class:`QEInput` object is a input handler for QE::

  from qepy.io import QEInput
  qeinput = QEInput()

List of all Methods
-------------------

.. autoclass:: QEInput
   :members:
